==> aws-java-sdk-cognitoidp-1.10.70-sources.jar: com/amazonaws/services/cognitoidp/model/transform/AddCustomAttributesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidp.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.cognitoidp.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * AddCustomAttributesRequest Marshaller
 */
public class AddCustomAttributesRequestMarshaller
        implements
        Marshaller<Request<AddCustomAttributesRequest>, AddCustomAttributesRequest> {

    public Request<AddCustomAttributesRequest> marshall(
            AddCustomAttributesRequest addCustomAttributesRequest) {

        if (addCustomAttributesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<AddCustomAttributesRequest> request = new DefaultRequest<AddCustomAttributesRequest>(
                addCustomAttributesRequest, "AWSCognitoIdentityProvider");
        request.addHeader("X-Amz-Target",
                "AWSCognitoIdentityProviderService.AddCustomAttributes");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = SdkJsonProtocolFactory
                    .createWriter(false, "1.1");

            jsonGenerator.writeStartObject();

            if (addCustomAttributesRequest.getUserPoolId() != null) {
                jsonGenerator.writeFieldName("UserPoolId").writeValue(
                        addCustomAttributesRequest.getUserPoolId());
            }

            java.util.List<SchemaAttributeType> customAttributesList = addCustomAttributesRequest
                    .getCustomAttributes();
            if (customAttributesList != null) {
                jsonGenerator.writeFieldName("CustomAttributes");
                jsonGenerator.writeStartArray();
                for (SchemaAttributeType customAttributesListValue : customAttributesList) {
                    if (customAttributesListValue != null) {

                        SchemaAttributeTypeJsonMarshaller.getInstance()
                                .marshall(customAttributesListValue,
                                        jsonGenerator);
                    }
                }
                jsonGenerator.writeEndArray();
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", jsonGenerator.getContentType());
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}

==> aws-java-sdk-cognitoidp-1.11.14-sources.jar: com/amazonaws/services/cognitoidp/model/transform/AddCustomAttributesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidp.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.cognitoidp.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * AddCustomAttributesRequest Marshaller
 */
public class AddCustomAttributesRequestMarshaller
        implements
        Marshaller<Request<AddCustomAttributesRequest>, AddCustomAttributesRequest> {

    private final SdkJsonProtocolFactory protocolFactory;

    public AddCustomAttributesRequestMarshaller(
            SdkJsonProtocolFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<AddCustomAttributesRequest> marshall(
            AddCustomAttributesRequest addCustomAttributesRequest) {

        if (addCustomAttributesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<AddCustomAttributesRequest> request = new DefaultRequest<AddCustomAttributesRequest>(
                addCustomAttributesRequest, "AWSCognitoIdentityProvider");
        request.addHeader("X-Amz-Target",
                "AWSCognitoIdentityProviderService.AddCustomAttributes");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory
                    .createGenerator();

            jsonGenerator.writeStartObject();

            if (addCustomAttributesRequest.getUserPoolId() != null) {
                jsonGenerator.writeFieldName("UserPoolId").writeValue(
                        addCustomAttributesRequest.getUserPoolId());
            }

            java.util.List<SchemaAttributeType> customAttributesList = addCustomAttributesRequest
                    .getCustomAttributes();
            if (customAttributesList != null) {
                jsonGenerator.writeFieldName("CustomAttributes");
                jsonGenerator.writeStartArray();
                for (SchemaAttributeType customAttributesListValue : customAttributesList) {
                    if (customAttributesListValue != null) {

                        SchemaAttributeTypeJsonMarshaller.getInstance()
                                .marshall(customAttributesListValue,
                                        jsonGenerator);
                    }
                }
                jsonGenerator.writeEndArray();
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}
